==> fans-common-core-1.0.9-sources.jar: com/ptteng/sca/fans/common/client/ClassifyContentsRelationSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.fans.common.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.fans.common.model.ClassifyContentsRelation;
import com.ptteng.fans.common.service.ClassifyContentsRelationService;
import java.util.List;
import java.util.Map;

public class ClassifyContentsRelationSCAClient implements ClassifyContentsRelationService {

    private ClassifyContentsRelationService classifyContentsRelationService;

	public ClassifyContentsRelationService getClassifyContentsRelationService() {
		return classifyContentsRelationService;
	}
	
	
	public void setClassifyContentsRelationService(
      ClassifyContentsRelationService classifyContentsRelationService) {
		this.classifyContentsRelationService =classifyContentsRelationService;
	}
	
	
			   
		@Override
		public Long insert(ClassifyContentsRelation classifyContentsRelation)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.insert(classifyContentsRelation);
		          
		
		}	
		  
    	   
		@Override
		public List<ClassifyContentsRelation> insertList(List<ClassifyContentsRelation> classifyContentsRelationList)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.insertList(classifyContentsRelationList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(ClassifyContentsRelation classifyContentsRelation)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.update(classifyContentsRelation);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<ClassifyContentsRelation> classifyContentsRelationList)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.updateList(classifyContentsRelationList);
		          
		
		}	
		  
    	   
		@Override
		public ClassifyContentsRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<ClassifyContentsRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getClassifyContentsRelationIdsByClassifyId(Long classifyId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.getClassifyContentsRelationIdsByClassifyId(classifyId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getClassifyContentsRelationIdsByContentsId(Long contentsId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.getClassifyContentsRelationIdsByContentsId(contentsId,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countClassifyContentsRelationIdsByClassifyId(Long classifyId)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.countClassifyContentsRelationIdsByClassifyId(classifyId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countClassifyContentsRelationIdsByContentsId(Long contentsId)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.countClassifyContentsRelationIdsByContentsId(contentsId);
	
	
	}
	
		
	
		@Override
	public List<Long> getClassifyContentsRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return classifyContentsRelationService.getClassifyContentsRelationIds(start, limit);
	}

	@Override
	public Integer countClassifyContentsRelationIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return classifyContentsRelationService.countClassifyContentsRelationIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return classifyContentsRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return classifyContentsRelationService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   classifyContentsRelationService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.classifyContentsRelationService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}


 
}

==> fans-common-core-1.1.3-sources.jar: com/ptteng/sca/fans/common/client/ClassifyContentsRelationSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.fans.common.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.fans.common.model.ClassifyContentsRelation;
import com.ptteng.fans.common.service.ClassifyContentsRelationService;
import java.util.List;
import java.util.Map;

public class ClassifyContentsRelationSCAClient implements ClassifyContentsRelationService {

    private ClassifyContentsRelationService classifyContentsRelationService;

	public ClassifyContentsRelationService getClassifyContentsRelationService() {
		return classifyContentsRelationService;
	}
	
	
	public void setClassifyContentsRelationService(
      ClassifyContentsRelationService classifyContentsRelationService) {
		this.classifyContentsRelationService =classifyContentsRelationService;
	}
	
	
			   
		@Override
		public Long insert(ClassifyContentsRelation classifyContentsRelation)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.insert(classifyContentsRelation);
		          
		
		}	
		  
    	   
		@Override
		public List<ClassifyContentsRelation> insertList(List<ClassifyContentsRelation> classifyContentsRelationList)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.insertList(classifyContentsRelationList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(ClassifyContentsRelation classifyContentsRelation)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.update(classifyContentsRelation);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<ClassifyContentsRelation> classifyContentsRelationList)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.updateList(classifyContentsRelationList);
		          
		
		}	
		  
    	   
		@Override
		public ClassifyContentsRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<ClassifyContentsRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getClassifyContentsRelationIdsByClassifyId(Long classifyId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.getClassifyContentsRelationIdsByClassifyId(classifyId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getClassifyContentsRelationIdsByContentsId(Long contentsId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.getClassifyContentsRelationIdsByContentsId(contentsId,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countClassifyContentsRelationIdsByClassifyId(Long classifyId)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.countClassifyContentsRelationIdsByClassifyId(classifyId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countClassifyContentsRelationIdsByContentsId(Long contentsId)throws ServiceException, ServiceDaoException{
		
		return classifyContentsRelationService.countClassifyContentsRelationIdsByContentsId(contentsId);
	
	
	}
	
		
	
		@Override
	public List<Long> getClassifyContentsRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return classifyContentsRelationService.getClassifyContentsRelationIds(start, limit);
	}

	@Override
	public Integer countClassifyContentsRelationIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return classifyContentsRelationService.countClassifyContentsRelationIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return classifyContentsRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return classifyContentsRelationService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   classifyContentsRelationService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.classifyContentsRelationService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}

    @Override
    public Object getMapListByDynamicCondition(Class clz,Map<String, Object> conditions, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
        return this.classifyContentsRelationService.getMapListByDynamicCondition(clz, conditions, start, limit);
    }


}
